@@ -1,11 +1,10 @@
 import logging
+from pathlib import Path
+from typing import Any, Dict, List, Optional, Union
 
 from glyphspkg.filenames import userNameToFileName
 from glyphspkg.paths import build_output_file_path
 from glyphspkg.plist import parse_plist_from_path, save_to_plist_path
-from pathlib import Path
-from typing import Any, Dict, List, Optional, Union
-
 
 logger = logging.getLogger(__name__)
 
@@ -13,6 +12,12 @@ logger = logging.getLogger(__name__)
 def package_to_single(input_path: Path, output_path: Optional[Path] = None) -> Path:
     # The main dict
     glyphs_file = convert_fontinfo(input_path)
+    if isinstance(glyphs_file, List):
+        logger.error(
+            "Parse error. The fontinfo file should parse as a dict, not list: "
+            f"{input_path}"
+        )
+        raise TypeError
 
     # Glyph order, is used to read individual glyphs files
     glyph_order = convert_order(input_path)
@@ -36,6 +41,13 @@ def package_to_single(input_path: Path, output_path: Optional[Path] = None) -> P
 
     # UIState, current display strings
     uistate = convert_uistate(input_path)
+    if isinstance(uistate, List):
+        logger.error(
+            "Parse error. The uistate file should parse as a dict, not list: "
+            f"{input_path}"
+        )
+        raise TypeError
+
     if uistate:
         # Why the different key casing?
         glyphs_file["DisplayStrings"] = uistate["displayStrings"]
