@@ -1,9 +1,9 @@
 import codecs
-import openstep_plist
-
 from pathlib import Path
 from typing import Any, Dict, List, Union
 
+import openstep_plist
+
 
 def parse_plist_from_path(
     plist_path: Path,
@@ -21,9 +21,7 @@ def save_to_plist_path(obj: Union[Dict[Any, Any], List[Any]], plist_path: Path)
             unicode_escape=False,
             indent=0,
             single_line_tuples=True,
-            # TODO: The released version 0.3.1 of openstep_plist doesn't have the
-            # ``escape_newlines`` argument
-            # escape_newlines=False,
+            escape_newlines=False,
         )
 
 
